# Contributing to GrowthBook OpenFeature Provider

We love your input! We want to make contributing as easy and transparent as possible.

## Development Process

1. Fork the repo and create your branch from `main`
2. Install development dependencies: `pip install -e ".[dev]"`
3. Make your changes
4. Add or update tests as needed
5. Run tests: `pytest`
6. Format code: `black . && isort .`
7. Submit a pull request

## Pull Request Process

1. Update the README.md with details of changes if needed
2. Update the CHANGELOG.md with your changes
3. The PR will be merged once you have the sign-off of maintainers

## Code Style

- We use `black` for code formatting
- We use `isort` for import sorting
- We aim for 100% test coverage for new code
